1. Each module is in the `/modules` folder.
2. Open the folder with the name of the module which you want to read. E.g.: `hex`.
3. Open the folder with the name of the first submodule which you want to read. E.g: `invert.py`.
4. (Optional) When you want to read the docs for a class open the folder with the name of the class. E.g.: `HexToCmyk`.
5. Open the .md file with the name of the function you want to call.